dotplotwithlm: Dot Plot with LM abline

Description Usage Arguments Value Examples

View source: R/dotplotwithlm.R

Description

Dot Plot with LM abline

Usage

1

Arguments

data

The data frame used for the dotplot and linear model.

x

The x-axis variable

y

The y-axis variable

Value

Outputs a dotplot with the linear model drawn onto it.

Examples

1
## Not run: spruce.df<-read.csv("Spruce.df");dotplotwithlm(data=spruce.df, x=BHDiameter, y=Height)

ShilohBeeler/shilohMATH4753 documentation built on Nov. 21, 2020, 9:10 a.m.