myboot2: A bootstrapping function which finds confidence intervals for...

Description Usage Arguments Value Examples

View source: R/myboot2.R

Description

A bootstrapping function which finds confidence intervals for population parameters given sample statistics.

Usage

1
myboot2(iter = 10000, x, fun = "mean", alpha = 0.05, cx = 1.5, ...)

Arguments

iter

The number of iterations to run.

x

The sample to draw from.

fun

The function for the statistic/parameter.

alpha

Used in (1-alpha)100 to determine the strength of the confidence interval.

cx

Character expansion factor for text.

...

Further arguments and graphical parameters passed to hist().

Value

A graph of the sampled values, the point estimate, and the confidence interval, alongside a returned list of those values.

Examples

1
## Not run: sam=rnorm(20); myboot2(x=sam)

ShilohBeeler/shilohMATH4753 documentation built on Nov. 21, 2020, 9:10 a.m.