Description Usage Arguments Value Examples
View source: R/dotplotwithlm.R
Dot Plot with LM abline
1 | dotplotwithlm(data, x, y)
|
data |
The data frame used for the dotplot and linear model. |
x |
The x-axis variable |
y |
The y-axis variable |
Outputs a dotplot with the linear model drawn onto it.
1 | ## Not run: spruce.df<-read.csv("Spruce.df");dotplotwithlm(data=spruce.df, x=BHDiameter, y=Height)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.