Description Usage Arguments Value Examples
A bootstrapping function which finds confidence intervals for population parameters given sample statistics.
1 |
iter |
The number of iterations to run. |
x |
The sample to draw from. |
fun |
The function for the statistic/parameter. |
alpha |
Used in (1-alpha)100 to determine the strength of the confidence interval. |
cx |
Character expansion factor for text. |
... |
Further arguments and graphical parameters passed to hist(). |
A graph of the sampled values, the point estimate, and the confidence interval, alongside a returned list of those values.
1 | ## Not run: sam=rnorm(20); myboot2(x=sam)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.